.. currentmodule:: pdcast

.. _integer_types:

Integer
=======

Generic
-------

.. _integer_type:

.. autoclass:: IntegerType

.. _signed_integer_type:

.. autoclass:: SignedIntegerType

.. _unsigned_integer_type:

.. autoclass:: UnsignedIntegerType

.. _int8_type:

.. autoclass:: Int8Type

.. _int16_type:

.. autoclass:: Int16Type

.. _int32_type:

.. autoclass:: Int32Type

.. _int64_type:

.. autoclass:: Int64Type

.. _uint8_type:

.. autoclass:: UInt8Type

.. _uint16_type:

.. autoclass:: UInt16Type

.. _uint32_type:

.. autoclass:: UInt32Type

.. _uint64_type:

.. autoclass:: UInt64Type

Numpy
-----

.. _numpy_integer_type:

.. autoclass:: NumpyIntegerType

.. _numpy_signed_integer_type:

.. autoclass:: NumpySignedIntegerType

.. _numpy_unsigned_integer_type:

.. autoclass:: NumpyUnsignedIntegerType

.. _numpy_int8_type:

.. autoclass:: NumpyInt8Type

.. _numpy_int16_type:

.. autoclass:: NumpyInt16Type

.. _numpy_int32_type:

.. autoclass:: NumpyInt32Type

.. _numpy_int64_type:

.. autoclass:: NumpyInt64Type

.. _numpy_uint8_type:

.. autoclass:: NumpyUInt8Type

.. _numpy_uint16_type:

.. autoclass:: NumpyUInt16Type

.. _numpy_uint32_type:

.. autoclass:: NumpyUInt32Type

.. _numpy_uint64_type:

.. autoclass:: NumpyUInt64Type

Pandas
------

.. _pandas_integer_type:

.. autoclass:: PandasIntegerType

.. _pandas_signed_integer_type:

.. autoclass:: PandasSignedIntegerType

.. _pandas_unsigned_integer_type:

.. autoclass:: PandasUnsignedIntegerType

.. _pandas_int8_type:

.. autoclass:: PandasInt8Type

.. _pandas_int16_type:

.. autoclass:: PandasInt16Type

.. _pandas_int32_type:

.. autoclass:: PandasInt32Type

.. _pandas_int64_type:

.. autoclass:: PandasInt64Type

.. _pandas_uint8_type:

.. autoclass:: PandasUInt8Type

.. _pandas_uint16_type:

.. autoclass:: PandasUInt16Type

.. _pandas_uint32_type:

.. autoclass:: PandasUInt32Type

.. _pandas_uint64_type:

.. autoclass:: PandasUInt64Type

Python
------

.. _python_integer_type:

.. autoclass:: PythonIntegerType
